
---
title: my_site
keywords: my_site
desc: my_site, 使用 teedoc 生成的网站
id: home_page
---




<div>
    <h1><span>my_site</span></h1>
    <h3>好耶~ 网站出现啦！</h3>
</div>
<div id="big_btn_wrapper">
    <div class="big_btn">
        <a href="/get_started/zh/">开始使用</a>
    </div>
</div>

